==> haskell-hslua-1.0.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua
version: 1.0.2
id: hslua-1.0.2-2NmqlS3i5bX7dgFH9R1Uz6
key: hslua-1.0.2-2NmqlS3i5bX7dgFH9R1Uz6
license: MIT
copyright: © 2007–2012 Gracjan Polak
           © 2012–2016 Ömer Sinan Ağacan
           © 2016–2019 Albert Krewinkel
maintainer: albert+hslua@zeitkraut.de
author: Gracjan Polak, Ömer Sinan Ağacan
homepage: https://hslua.github.io/
synopsis: Bindings to Lua, an embeddable scripting language
description:
    HsLua provides bindings, wrappers, types, and helper
    functions to bridge Haskell and <https://www.lua.org/ Lua>.
    .
    This package contains a full Lua interpreter version 5.3.5.
    If you want to link it with a system-wide Lua installation,
    use the @system-lua@ flag.
    .
    <https://github.com/hslua/hslua-examples Example programs>
    are available in a separate repository.
category: Foreign
abi: a53a9f1b95b2a0dd6330de0e9c73b479
exposed: True
exposed-modules:
    Foreign.Lua Foreign.Lua.Core Foreign.Lua.Core.Constants
    Foreign.Lua.Core.Error Foreign.Lua.Core.RawBindings
    Foreign.Lua.Core.Types Foreign.Lua.FunctionCalling
    Foreign.Lua.Types Foreign.Lua.Types.Peekable
    Foreign.Lua.Types.Pushable Foreign.Lua.Userdata Foreign.Lua.Util
hidden-modules: Foreign.Lua.Utf8 Foreign.Lua.Core.Auxiliary
                Foreign.Lua.Core.Functions
import-dirs: /usr/lib/ghc-8.6.3/site-local/hslua-1.0.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/hslua-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/hslua-1.0.2
hs-libraries: HShslua-1.0.2-2NmqlS3i5bX7dgFH9R1Uz6
extra-libraries:
    lua m
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    exceptions-0.10.0-29UXSV5bKJ4B0H4dLl5Nff mtl-2.2.2 text-1.2.3.1
ld-options: "-Wl,-E"
haddock-interfaces: /usr/share/doc/haskell-hslua/html/hslua.haddock
haddock-html: /usr/share/doc/haskell-hslua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-1.0.2-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua
version: 1.0.2
id: hslua-1.0.2-yiHyC7k3ro8EoTA50yWro
key: hslua-1.0.2-yiHyC7k3ro8EoTA50yWro
license: MIT
copyright: © 2007–2012 Gracjan Polak
           © 2012–2016 Ömer Sinan Ağacan
           © 2016–2019 Albert Krewinkel
maintainer: albert+hslua@zeitkraut.de
author: Gracjan Polak, Ömer Sinan Ağacan
homepage: https://hslua.github.io/
synopsis: Bindings to Lua, an embeddable scripting language
description:
    HsLua provides bindings, wrappers, types, and helper
    functions to bridge Haskell and <https://www.lua.org/ Lua>.
    .
    This package contains a full Lua interpreter version 5.3.5.
    If you want to link it with a system-wide Lua installation,
    use the @system-lua@ flag.
    .
    <https://github.com/hslua/hslua-examples Example programs>
    are available in a separate repository.
category: Foreign
abi: 3c968d15eb0b38caf08697b991914c31
exposed: True
exposed-modules:
    Foreign.Lua Foreign.Lua.Core Foreign.Lua.Core.Constants
    Foreign.Lua.Core.Error Foreign.Lua.Core.RawBindings
    Foreign.Lua.Core.Types Foreign.Lua.FunctionCalling
    Foreign.Lua.Types Foreign.Lua.Types.Peekable
    Foreign.Lua.Types.Pushable Foreign.Lua.Userdata Foreign.Lua.Util
hidden-modules: Foreign.Lua.Utf8 Foreign.Lua.Core.Auxiliary
                Foreign.Lua.Core.Functions
import-dirs: /usr/lib/ghc-8.6.3/site-local/hslua-1.0.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/hslua-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/hslua-1.0.2
hs-libraries: HShslua-1.0.2-yiHyC7k3ro8EoTA50yWro
extra-libraries:
    lua m
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    exceptions-0.10.0-29UXSV5bKJ4B0H4dLl5Nff mtl-2.2.2 text-1.2.3.1
ld-options: "-Wl,-E"
haddock-interfaces: /usr/share/doc/haskell-hslua/html/hslua.haddock
haddock-html: /usr/share/doc/haskell-hslua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
